aboutsummaryrefslogtreecommitdiffstats
path: root/src/xterm.h
diff options
context:
space:
mode:
authorKim F. Storm <[email protected]>2001-11-16 13:19:19 +0000
committerKim F. Storm <[email protected]>2001-11-16 13:19:19 +0000
commitf76e1b5f70328303f325f771945b53c475bbcd9f (patch)
tree0081da4d3f4542cbddf13ba83ee0edf38a19c059 /src/xterm.h
parenta0a1947c5a1786c7297e3c843ea52b8c8b972b00 (diff)
Fringe cleanup.
Comment fixes. Use renamed symbols. (fringes_extra): Renamed from flags_areas_extra. (FRAME_FRINGE_BITMAP_WIDTH): Renamed from FRAME_FLAGS_BITMAP_WIDTH. (FRAME_FRINGE_BITMAP_HEIGHT): Renamed from FRAME_FLAGS_BITMAP_HEIGHT. (FRAME_X_FRINGE_COLS): Renamed from FRAME_X_FLAGS_AREA_COLS. (FRAME_X_FRINGE_WIDTH): Renamed from FRAME_X_FLAGS_AREA_WIDTH. (FRAME_X_LEFT_FRINGE_WIDTH): Renamed from FRAME_X_LEFT_FLAGS_AREA_WIDTH. (FRAME_X_RIGHT_FRINGE_WIDTH): Renamed from FRAME_X_RIGHT_FLAGS_AREA_WIDTH.
Diffstat (limited to 'src/xterm.h')
-rw-r--r--src/xterm.h36
1 files changed, 18 insertions, 18 deletions
diff --git a/src/xterm.h b/src/xterm.h
index c59de131cc..f9d3d7a809 100644
--- a/src/xterm.h
+++ b/src/xterm.h
@@ -537,7 +537,7 @@ struct x_output
/* The extra width currently allotted for the areas in which
truncation marks, continuation marks, and overlay arrows are
displayed. */
- int flags_areas_extra;
+ int fringes_extra;
/* This is the gravity value for the specified window position. */
int win_gravity;
@@ -661,38 +661,38 @@ struct x_output
#define FRAME_X_IMAGE_CACHE(F) FRAME_X_DISPLAY_INFO ((F))->image_cache
/* Pixel width of the bitmaps drawn to indicate truncation,
continuation etc. */
#define FRAME_FLAGS_BITMAP_WIDTH(f) 8
#define FRAME_FLAGS_BITMAP_HEIGHT(f) 8
/* Total width of a areas reserved for drawing truncation bitmaps,
continuation bitmaps and alike. The width is in canonical char
units of the frame. This must currently be the case because window
sizes aren't pixel values. If it weren't the case, we wouldn't be
able to split windows horizontally nicely. */
-#define FRAME_X_FLAGS_AREA_COLS(F) \
- ((2 * FRAME_FLAGS_BITMAP_WIDTH ((F)) + CANON_X_UNIT ((F)) - 1) \
+#define FRAME_X_FRINGE_COLS(F) \
+ ((2 * FRAME_FRINGE_BITMAP_WIDTH ((F)) + CANON_X_UNIT ((F)) - 1) \
/ CANON_X_UNIT ((F)))
-/* Total width of flags areas in pixels. */
+/* Total width of fringes in pixels. */
-#define FRAME_X_FLAGS_AREA_WIDTH(F) \
- (FRAME_X_FLAGS_AREA_COLS ((F)) * CANON_X_UNIT ((F)))
+#define FRAME_X_FRINGE_WIDTH(F) \
+ (FRAME_X_FRINGE_COLS ((F)) * CANON_X_UNIT ((F)))
-/* Pixel-width of the left flags area. */
+/* Pixel-width of the left fringe. */
-#define FRAME_X_LEFT_FLAGS_AREA_WIDTH(F) \
- (FRAME_X_FLAGS_AREA_WIDTH (F) / 2)
+#define FRAME_X_LEFT_FRINGE_WIDTH(F) \
+ (FRAME_X_FRINGE_WIDTH (F) / 2)
-/* Pixel-width of the right flags area. Note that we are doing
+/* Pixel-width of the right fringe. Note that we are doing
integer arithmetic here, so don't loose a pixel if the total
width is an odd number. */
-#define FRAME_X_RIGHT_FLAGS_AREA_WIDTH(F) \
- (FRAME_X_FLAGS_AREA_WIDTH (F) - FRAME_X_FLAGS_AREA_WIDTH (F) / 2)
+#define FRAME_X_RIGHT_FRINGE_WIDTH(F) \
+ (FRAME_X_FRINGE_WIDTH (F) - FRAME_X_FRINGE_WIDTH (F) / 2)
@@ -855,7 +855,7 @@ struct scroll_bar
#define CHAR_TO_PIXEL_WIDTH(f, width) \
(CHAR_TO_PIXEL_COL (f, width) \
+ (f)->output_data.x->vertical_scroll_bar_extra \
- + (f)->output_data.x->flags_areas_extra \
+ + (f)->output_data.x->fringes_extra \
+ (f)->output_data.x->internal_border_width)
#define CHAR_TO_PIXEL_HEIGHT(f, height) \
(CHAR_TO_PIXEL_ROW (f, height) \
@@ -876,7 +876,7 @@ struct scroll_bar
#define PIXEL_TO_CHAR_WIDTH(f, width) \
(PIXEL_TO_CHAR_COL (f, ((width) \
- (f)->output_data.x->internal_border_width \
- - (f)->output_data.x->flags_areas_extra \
+ - (f)->output_data.x->fringes_extra \
- (f)->output_data.x->vertical_scroll_bar_extra)))
#define PIXEL_TO_CHAR_HEIGHT(f, height) \
(PIXEL_TO_CHAR_ROW (f, ((height) \
@@ -661,38 +661,38 @@ struct x_output
#define FRAME_X_IMAGE_CACHE(F) FRAME_X_DISPLAY_INFO ((F))->image_cache
-/* Pixel width of the bitmaps drawn to indicate truncation,
+/* Pixel width of the fringe bitmaps drawn to indicate truncation,
continuation etc. */
@@ -661,38 +661,38 @@ struct x_output
continuation etc. */
-#define FRAME_FLAGS_BITMAP_WIDTH(f) 8
-#define FRAME_FLAGS_BITMAP_HEIGHT(f) 8
+#define FRAME_FRINGE_BITMAP_WIDTH(f) 8
+#define FRAME_FRINGE_BITMAP_HEIGHT(f) 8
-/* Total width of a areas reserved for drawing truncation bitmaps,
+/* Total width of fringes reserved for drawing truncation bitmaps,
continuation bitmaps and alike. The width is in canonical char
units of the frame. This must currently be the case because window